<?php

namespace Drupal\partial_datelist;

/**
 * This class defines basic module configuration.
 *
 * @category Drupal
 * @author Marcos Buarque de Hollanda
 * @license https://www.gnu.org/licenses/gpl-2.0.html GNU General Public License,
 *   version 2 or later
 */
class PartialDatelistConfig {

  /**
   * Date part definitions for the module.
   *
   * Structure:
   * - key: The date part machine name
   *   - setting: The form setting key that controls visibility
   *   - label: Human-readable label
   *   - context: Array of supported field types
   */
  const DATELIST_PARTS = [
    'year' => [
      'setting' => 'hide_year',
      'label' => 'Year',
      'context' => [
        'date',
        'datetime',
      ],
    ],
    'month' => [
      'setting' => 'hide_month',
      'label' => 'Month',
      'context' => [
        'date',
        'datetime',
      ],
    ],
    'day' => [
      'setting' => 'hide_day',
      'label' => 'Day',
      'context' => [
        'date',
        'datetime',
      ],
    ],
    'hour' => [
      'setting' => 'hide_hour',
      'label' => 'Hour',
      'context' => [
        'datetime',
      ],
    ],
    'minute' => [
      'setting' => 'hide_minute',
      'label' => 'Minute',
      'context' => [
        'datetime',
      ],
    ],
    'second' => [
      'setting' => 'hide_second',
      'label' => 'Second',
      'context' => [
        'datetime',
      ],
    ],
  ];

  const DATELIST_SETTINGS_CLASS_NAME = 'partial-datelist-settings';

}
